#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'Emulation.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/pub/devel/octave/octave-6.4.0-1.i686/src/octave-6.4.0/libgui/qterminal/libqterminal/unix/Emulation.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Emulation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Emulation_t {
    QByteArrayData data[46];
    char stringdata0[543];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Emulation_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Emulation_t qt_meta_stringdata_Emulation = {
    {
QT_MOC_LITERAL(0, 0, 9), // "Emulation"
QT_MOC_LITERAL(1, 10, 8), // "sendData"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 11), // "const char*"
QT_MOC_LITERAL(4, 32, 4), // "data"
QT_MOC_LITERAL(5, 37, 3), // "len"
QT_MOC_LITERAL(6, 41, 14), // "lockPtyRequest"
QT_MOC_LITERAL(7, 56, 7), // "suspend"
QT_MOC_LITERAL(8, 64, 14), // "useUtf8Request"
QT_MOC_LITERAL(9, 79, 8), // "stateSet"
QT_MOC_LITERAL(10, 88, 5), // "state"
QT_MOC_LITERAL(11, 94, 25), // "changeTabTextColorRequest"
QT_MOC_LITERAL(12, 120, 5), // "color"
QT_MOC_LITERAL(13, 126, 23), // "programUsesMouseChanged"
QT_MOC_LITERAL(14, 150, 9), // "usesMouse"
QT_MOC_LITERAL(15, 160, 32), // "programBracketedPasteModeChanged"
QT_MOC_LITERAL(16, 193, 18), // "bracketedPasteMode"
QT_MOC_LITERAL(17, 212, 13), // "outputChanged"
QT_MOC_LITERAL(18, 226, 12), // "titleChanged"
QT_MOC_LITERAL(19, 239, 5), // "title"
QT_MOC_LITERAL(20, 245, 8), // "newTitle"
QT_MOC_LITERAL(21, 254, 16), // "imageSizeChanged"
QT_MOC_LITERAL(22, 271, 9), // "lineCount"
QT_MOC_LITERAL(23, 281, 11), // "columnCount"
QT_MOC_LITERAL(24, 293, 28), // "profileChangeCommandReceived"
QT_MOC_LITERAL(25, 322, 4), // "text"
QT_MOC_LITERAL(26, 327, 12), // "setImageSize"
QT_MOC_LITERAL(27, 340, 5), // "lines"
QT_MOC_LITERAL(28, 346, 7), // "columns"
QT_MOC_LITERAL(29, 354, 8), // "sendText"
QT_MOC_LITERAL(30, 363, 12), // "sendKeyEvent"
QT_MOC_LITERAL(31, 376, 10), // "QKeyEvent*"
QT_MOC_LITERAL(32, 387, 14), // "sendMouseEvent"
QT_MOC_LITERAL(33, 402, 7), // "buttons"
QT_MOC_LITERAL(34, 410, 6), // "column"
QT_MOC_LITERAL(35, 417, 4), // "line"
QT_MOC_LITERAL(36, 422, 9), // "eventType"
QT_MOC_LITERAL(37, 432, 10), // "sendString"
QT_MOC_LITERAL(38, 443, 6), // "string"
QT_MOC_LITERAL(39, 450, 6), // "length"
QT_MOC_LITERAL(40, 457, 11), // "receiveData"
QT_MOC_LITERAL(41, 469, 6), // "buffer"
QT_MOC_LITERAL(42, 476, 14), // "bufferedUpdate"
QT_MOC_LITERAL(43, 491, 8), // "showBulk"
QT_MOC_LITERAL(44, 500, 16), // "usesMouseChanged"
QT_MOC_LITERAL(45, 517, 25) // "bracketedPasteModeChanged"

    },
    "Emulation\0sendData\0\0const char*\0data\0"
    "len\0lockPtyRequest\0suspend\0useUtf8Request\0"
    "stateSet\0state\0changeTabTextColorRequest\0"
    "color\0programUsesMouseChanged\0usesMouse\0"
    "programBracketedPasteModeChanged\0"
    "bracketedPasteMode\0outputChanged\0"
    "titleChanged\0title\0newTitle\0"
    "imageSizeChanged\0lineCount\0columnCount\0"
    "profileChangeCommandReceived\0text\0"
    "setImageSize\0lines\0columns\0sendText\0"
    "sendKeyEvent\0QKeyEvent*\0sendMouseEvent\0"
    "buttons\0column\0line\0eventType\0sendString\0"
    "string\0length\0receiveData\0buffer\0"
    "bufferedUpdate\0showBulk\0usesMouseChanged\0"
    "bracketedPasteModeChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Emulation[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      22,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  124,    2, 0x06 /* Public */,
       6,    1,  129,    2, 0x06 /* Public */,
       8,    1,  132,    2, 0x06 /* Public */,
       9,    1,  135,    2, 0x06 /* Public */,
      11,    1,  138,    2, 0x06 /* Public */,
      13,    1,  141,    2, 0x06 /* Public */,
      15,    1,  144,    2, 0x06 /* Public */,
      17,    0,  147,    2, 0x06 /* Public */,
      18,    2,  148,    2, 0x06 /* Public */,
      21,    2,  153,    2, 0x06 /* Public */,
      24,    1,  158,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      26,    2,  161,    2, 0x0a /* Public */,
      29,    1,  166,    2, 0x0a /* Public */,
      30,    1,  169,    2, 0x0a /* Public */,
      32,    4,  172,    2, 0x0a /* Public */,
      37,    2,  181,    2, 0x0a /* Public */,
      37,    1,  186,    2, 0x2a /* Public | MethodCloned */,
      40,    2,  189,    2, 0x0a /* Public */,
      42,    0,  194,    2, 0x09 /* Protected */,
      43,    0,  195,    2, 0x08 /* Private */,
      44,    1,  196,    2, 0x08 /* Private */,
      45,    1,  199,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   19,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   22,   23,
    QMetaType::Void, QMetaType::QString,   25,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   27,   28,
    QMetaType::Void, QMetaType::QString,   25,
    QMetaType::Void, 0x80000000 | 31,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   33,   34,   35,   36,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,   38,   39,
    QMetaType::Void, 0x80000000 | 3,   38,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,   41,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, QMetaType::Bool,   16,

       0        // eod
};

void Emulation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Emulation *_t = static_cast<Emulation *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->sendData((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->lockPtyRequest((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->useUtf8Request((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->stateSet((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->changeTabTextColorRequest((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->programUsesMouseChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->programBracketedPasteModeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->outputChanged(); break;
        case 8: _t->titleChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 9: _t->imageSizeChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->profileChangeCommandReceived((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->setImageSize((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 12: _t->sendText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->sendKeyEvent((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 14: _t->sendMouseEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 15: _t->sendString((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 16: _t->sendString((*reinterpret_cast< const char*(*)>(_a[1]))); break;
        case 17: _t->receiveData((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 18: _t->bufferedUpdate(); break;
        case 19: _t->showBulk(); break;
        case 20: _t->usesMouseChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->bracketedPasteModeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Emulation::*_t)(const char * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::sendData)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Emulation::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::lockPtyRequest)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Emulation::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::useUtf8Request)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Emulation::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::stateSet)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Emulation::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::changeTabTextColorRequest)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Emulation::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::programUsesMouseChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Emulation::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::programBracketedPasteModeChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Emulation::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::outputChanged)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (Emulation::*_t)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::titleChanged)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (Emulation::*_t)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::imageSizeChanged)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (Emulation::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::profileChangeCommandReceived)) {
                *result = 10;
                return;
            }
        }
    }
}

const QMetaObject Emulation::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Emulation.data,
      qt_meta_data_Emulation,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Emulation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Emulation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Emulation.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Emulation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void Emulation::sendData(const char * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Emulation::lockPtyRequest(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Emulation::useUtf8Request(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Emulation::stateSet(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Emulation::changeTabTextColorRequest(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Emulation::programUsesMouseChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Emulation::programBracketedPasteModeChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Emulation::outputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Emulation::titleChanged(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Emulation::imageSizeChanged(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Emulation::profileChangeCommandReceived(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
